#!/usr/bin/env python
# -*- coding: utf-8 -*-

u"""
django-sections
"""
__author__ = u"Rafał Selewońko <rafal@selewonko.com>"
__version__ = '0.1'
default_app_config = 'gipsy.sections.apps.GipsySections'
